@@ -6,15 +6,14 @@ from aiohttp import web
 from motor.motor_asyncio import AsyncIOMotorClient
 
 
-@asyncio.coroutine
-def setup_db():
+async def setup_db():
     db = AsyncIOMotorClient().test
-    yield from db.pages.drop()
+    await db.pages.drop()
     html = '<html><body>{}</body></html>'
-    yield from db.pages.insert_one({'_id': 'page-one',
+    await db.pages.insert_one({'_id': 'page-one',
                                     'body': html.format('Hello!')})
 
-    yield from db.pages.insert_one({'_id': 'page-two',
+    await db.pages.insert_one({'_id': 'page-two',
                                     'body': html.format('Goodbye.')})
 
     return db
@@ -22,8 +21,7 @@ def setup_db():
 
 
 # -- handler-start --
-@asyncio.coroutine
-def page_handler(request):
+async def page_handler(request):
     # If the visitor gets "/pages/page-one", then page_name is "page-one".
     page_name = request.match_info.get('page_name')
 
@@ -31,7 +29,7 @@ def page_handler(request):
     db = request.app['db']
 
     # Find the page by its unique id.
-    document = yield from db.pages.find_one(page_name)
+    document = await db.pages.find_one(page_name)
 
     if not document:
         return web.HTTPNotFound(text='No page named {!r}'.format(page_name))
