@@ -14,11 +14,7 @@
 
 """Motor, an asynchronous driver for MongoDB."""
 
-from __future__ import unicode_literals, absolute_import
-
-from motor.motor_py2_compat import text_type
-
-version_tuple = (2, 1, 0)
+version_tuple = (2, 3, 0)
 
 
 def get_version_string():
