@@ -12,13 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, absolute_import
-
 """Framework-agnostic core of Motor, an asynchronous driver for MongoDB."""
 
 import functools
 import sys
-import textwrap
+import warnings
 
 import pymongo
 import pymongo.auth
@@ -44,7 +42,6 @@ from .metaprogramming import (AsyncCommand,
                               coroutine_annotation,
                               create_class_with_framework,
                               DelegateMethod,
-                              motor_coroutine,
                               MotorCursorChainingMethod,
                               ReadOnlyProperty,
                               unwrap_args_session,
@@ -59,8 +56,6 @@ except ImportError:
     ssl = None
     HAS_SSL = False
 
-PY35 = sys.version_info >= (3, 5)
-
 # From the Convenient API for Transactions spec, with_transaction must
 # halt retries after 120 seconds.
 # This limit is non-configurable and was chosen to be twice the 60 second
@@ -135,7 +130,7 @@ class AgnosticClient(AgnosticBaseProperties):
     server_info              = AsyncRead()
     server_selection_timeout = ReadOnlyProperty()
     start_session            = AsyncCommand(doc=start_session_doc).wrap(ClientSession)
-    unlock                   = AsyncCommand()
+    unlock                   = AsyncCommand(doc=unlock_doc)
 
     def __init__(self, *args, **kwargs):
         """Create a new connection to a single MongoDB instance at *host:port*.
@@ -159,7 +154,7 @@ class AgnosticClient(AgnosticBaseProperties):
             DriverInfo('Motor', motor_version, self._framework.platform_info()))
 
         delegate = self.__delegate_class__(*args, **kwargs)
-        super(AgnosticBaseProperties, self).__init__(delegate)
+        super().__init__(delegate)
         self.io_loop = io_loop
 
     def get_io_loop(self):
@@ -270,18 +265,15 @@ class _MotorTransactionContext(object):
     def __init__(self, session):
         self._session = session
 
-    if PY35:
-        exec(textwrap.dedent("""
-        async def __aenter__(self):
-            return self
+    async def __aenter__(self):
+        return self
 
-        async def __aexit__(self, exc_type, exc_val, exc_tb):
-            if self._session.in_transaction:
-                if exc_val is None:
-                    await self._session.commit_transaction()
-                else:
-                    await self._session.abort_transaction()
-        """), globals(), locals())
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        if self._session.in_transaction:
+            if exc_val is None:
+                await self._session.commit_transaction()
+            else:
+                await self._session.abort_transaction()
 
 
 class AgnosticClientSession(AgnosticBase):
@@ -324,11 +316,92 @@ class AgnosticClientSession(AgnosticBase):
     def get_io_loop(self):
         return self._client.get_io_loop()
 
-    if PY35:
-        exec(textwrap.dedent("""
     async def with_transaction(self, coro, read_concern=None,
                                write_concern=None, read_preference=None,
                                max_commit_time_ms=None):
+        """Executes an awaitable in a transaction.
+
+        This method starts a transaction on this session, awaits ``coro``
+        once, and then commits the transaction. For example::
+
+          async def coro(session):
+              orders = session.client.db.orders
+              inventory = session.client.db.inventory
+              inserted_id = await orders.insert_one(
+                  {"sku": "abc123", "qty": 100}, session=session)
+              await inventory.update_one(
+                  {"sku": "abc123", "qty": {"$gte": 100}},
+                  {"$inc": {"qty": -100}}, session=session)
+              return inserted_id
+
+          async with await client.start_session() as session:
+              inserted_id = await session.with_transaction(coro)
+
+        To pass arbitrary arguments to the ``coro``, wrap it with a
+        ``lambda`` like this::
+
+          async def coro(session, custom_arg, custom_kwarg=None):
+              # Transaction operations...
+
+          async with await client.start_session() as session:
+              await session.with_transaction(
+                  lambda s: coro(s, "custom_arg", custom_kwarg=1))
+
+        In the event of an exception, ``with_transaction`` may retry the commit
+        or the entire transaction, therefore ``coro`` may be awaited
+        multiple times by a single call to ``with_transaction``. Developers
+        should be mindful of this possiblity when writing a ``coro`` that
+        modifies application state or has any other side-effects.
+        Note that even when the ``coro`` is invoked multiple times,
+        ``with_transaction`` ensures that the transaction will be committed
+        at-most-once on the server.
+
+        The ``coro`` should not attempt to start new transactions, but
+        should simply run operations meant to be contained within a
+        transaction. The ``coro`` should also not commit the transaction;
+        this is handled automatically by ``with_transaction``. If the
+        ``coro`` does commit or abort the transaction without error,
+        however, ``with_transaction`` will return without taking further
+        action.
+
+        When ``coro`` raises an exception, ``with_transaction``
+        automatically aborts the current transaction. When ``coro`` or
+        :meth:`~ClientSession.commit_transaction` raises an exception that
+        includes the ``"TransientTransactionError"`` error label,
+        ``with_transaction`` starts a new transaction and re-executes
+        the ``coro``.
+
+        When :meth:`~ClientSession.commit_transaction` raises an exception with
+        the ``"UnknownTransactionCommitResult"`` error label,
+        ``with_transaction`` retries the commit until the result of the
+        transaction is known.
+
+        This method will cease retrying after 120 seconds has elapsed. This
+        timeout is not configurable and any exception raised by the
+        ``coro`` or by :meth:`ClientSession.commit_transaction` after the
+        timeout is reached will be re-raised. Applications that desire a
+        different timeout duration should not use this method.
+
+        :Parameters:
+          - `coro`: The coroutine to run inside a transaction. The coroutine must
+            accept a single argument, this session. Note, under certain error
+            conditions the coroutine may be run multiple times.
+          - `read_concern` (optional): The
+            :class:`~pymongo.read_concern.ReadConcern` to use for this
+            transaction.
+          - `write_concern` (optional): The
+            :class:`~pymongo.write_concern.WriteConcern` to use for this
+            transaction.
+          - `read_preference` (optional): The read preference to use for this
+            transaction. If ``None`` (the default) the :attr:`read_preference`
+            of this :class:`Database` is used. See
+            :mod:`~pymongo.read_preferences` for options.
+
+        :Returns:
+          The return value of the ``coro``.
+
+        .. versionadded:: 2.1
+        """
         start_time = pymongo.monotonic.time()
         while True:
             async with self.start_transaction(
@@ -369,8 +442,6 @@ class AgnosticClientSession(AgnosticBase):
                 # Commit succeeded.
                 return ret
 
-    with_transaction.__doc__ = with_transaction_doc"""), globals(), locals())
-
     def start_transaction(self, read_concern=None, write_concern=None,
                           read_preference=None, max_commit_time_ms=None):
         """Start a multi-statement transaction.
@@ -400,14 +471,11 @@ class AgnosticClientSession(AgnosticBase):
         """The :class:`~MotorClient` this session was created from. """
         return self._client
 
-    if PY35:
-        exec(textwrap.dedent("""
-        async def __aenter__(self):
-            return self
-    
-        async def __aexit__(self, exc_type, exc_val, exc_tb):
-            self.delegate.__exit__(exc_type, exc_val, exc_tb)
-        """), globals(), locals())
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        self.delegate.__exit__(exc_type, exc_val, exc_tb)
 
     def __enter__(self):
         raise AttributeError("Use Motor sessions like 'async with await"
@@ -448,7 +516,7 @@ class AgnosticDatabase(AgnosticBaseProperties):
         delegate = kwargs.get('_delegate') or Database(
             client.delegate, name, **kwargs)
 
-        super(self.__class__, self).__init__(delegate)
+        super().__init__(delegate)
 
     def aggregate(self, pipeline, **kwargs):
         """Execute an aggregation pipeline on this database.
@@ -479,17 +547,9 @@ class AgnosticDatabase(AgnosticBaseProperties):
         Returns a :class:`MotorCommandCursor` that can be iterated like a
         cursor from :meth:`find`::
 
-           # Lists all operations currently running on the server.
-           pipeline = [{"$currentOp": {}}]
-           cursor = client.admin.aggregate(pipeline)
-           while (yield cursor.fetch_next):
-               operation = cursor.next_object()
-               print(operation)
-
-        In Python 3.5 and newer, aggregation cursors can be iterated elegantly
-        in native coroutines with `async for`::
-
            async def f():
+               # Lists all operations currently running on the server.
+               pipeline = [{"$currentOp": {}}]
                async for operation in client.admin.aggregate(pipeline):
                    print(operation)
 
@@ -650,7 +710,7 @@ class AgnosticCollection(AgnosticBaseProperties):
     map_reduce               = AsyncCommand(doc=mr_doc).wrap(Collection)
     name                     = ReadOnlyProperty()
     options                  = AsyncRead()
-    reindex                  = AsyncCommand()
+    reindex                  = AsyncCommand(doc=reindex_doc)
     rename                   = AsyncCommand()
     replace_one              = AsyncCommand(doc=replace_one_doc)
     update_many              = AsyncCommand(doc=update_many_doc)
@@ -676,7 +736,7 @@ class AgnosticCollection(AgnosticBaseProperties):
             read_preference=read_preference, write_concern=write_concern,
             read_concern=read_concern)
 
-        super(self.__class__, self).__init__(delegate)
+        super().__init__(delegate)
         self.database = database
 
     def __getattr__(self, name):
@@ -765,16 +825,8 @@ class AgnosticCollection(AgnosticBaseProperties):
         Returns a :class:`MotorCommandCursor` that can be iterated like a
         cursor from :meth:`find`::
 
-          pipeline = [{'$project': {'name': {'$toUpper': '$name'}}}]
-          cursor = collection.aggregate(pipeline)
-          while (yield cursor.fetch_next):
-              doc = cursor.next_object()
-              print(doc)
-
-        In Python 3.5 and newer, aggregation cursors can be iterated elegantly
-        in native coroutines with `async for`::
-
           async def f():
+              pipeline = [{'$project': {'name': {'$toUpper': '$name'}}}]
               async for doc in collection.aggregate(pipeline):
                   print(doc)
 
@@ -799,7 +851,7 @@ class AgnosticCollection(AgnosticBaseProperties):
 
         .. versionchanged:: 0.5
            :meth:`aggregate` now returns a cursor by default,
-           and the cursor is returned immediately without a ``yield``.
+           and the cursor is returned immediately without an ``await``.
            See :ref:`aggregation changes in Motor 0.5 <aggregate_changes_0_5>`.
 
         .. versionchanged:: 0.2
@@ -989,7 +1041,7 @@ class AgnosticCollection(AgnosticBaseProperties):
 
         If the only index is the default index on ``_id``, this might print::
 
-            SON([('v', 1), ('key', SON([('_id', 1)])), ('name', '_id_'), ('ns', 'test.test')])
+            SON([('v', 1), ('key', SON([('_id', 1)])), ('name', '_id_')])
         """
         cursor_class = create_class_with_framework(
             AgnosticLatentCommandCursor, self._framework, self.__module__)
@@ -1039,28 +1091,30 @@ class AgnosticBaseCursor(AgnosticBase):
         .. note::
           There is no need to manually close cursors; they are closed
           by the server after being fully iterated
-          with :meth:`to_list`, :meth:`each`, or :attr:`fetch_next`, or
+          with :meth:`to_list`, :meth:`each`, or `async for`, or
           automatically closed by the client when the :class:`MotorCursor` is
           cleaned up by the garbage collector.
         """
         # 'cursor' is a PyMongo Cursor, CommandCursor, or a _LatentCursor.
-        super(AgnosticBaseCursor, self).__init__(delegate=cursor)
+        super().__init__(delegate=cursor)
         self.collection = collection
         self.started = False
         self.closed = False
 
     # python.org/dev/peps/pep-0492/#api-design-and-implementation-revisions
-    if PY35:
-        exec(textwrap.dedent("""
-        def __aiter__(self):
-            return self
+    def __aiter__(self):
+        return self
 
-        async def __anext__(self):
-            # An optimization: skip the "await" if possible.
-            if self._buffer_size() or await self.fetch_next:
-                return self.next_object()
-            raise StopAsyncIteration()
-        """), globals(), locals())
+    async def next(self):
+        """Advance the cursor.
+
+        .. versionadded:: 2.2
+        """
+        if self.alive and (self._buffer_size() or await self._get_more()):
+            return next(self.delegate)
+        raise StopAsyncIteration
+
+    __anext__ = next
 
     def _get_more(self):
         """Initial query or getMore. Returns a Future."""
@@ -1075,53 +1129,63 @@ class AgnosticBaseCursor(AgnosticBase):
     @property
     @coroutine_annotation
     def fetch_next(self):
-        """A Future used with `gen.coroutine`_ to asynchronously retrieve the
-        next document in the result set, fetching a batch of documents from the
-        server if necessary. Resolves to ``False`` if there are no more
-        documents, otherwise :meth:`next_object` is guaranteed to return a
-        document.
-
-        .. _`gen.coroutine`: http://tornadoweb.org/en/stable/gen.html
+        """**DEPRECATED** - A Future used with `gen.coroutine`_ to
+        asynchronously retrieve the next document in the result set,
+        fetching a batch of documents from the server if necessary.
+        Resolves to ``False`` if there are no more documents, otherwise
+        :meth:`next_object` is guaranteed to return a document:
 
         .. doctest:: fetch_next
-          :hide:
+           :hide:
 
-          >>> _ = MongoClient().test.test_collection.delete_many({})
-          >>> collection = MotorClient().test.test_collection
+           >>> _ = MongoClient().test.test_collection.delete_many({})
+           >>> collection = MotorClient().test.test_collection
 
-        .. doctest:: fetch_next
+        .. attention:: The :attr:`fetch_next` property is deprecated and will
+           be removed in Motor 3.0. Use `async for` to iterate elegantly and
+           efficiently over :class:`MotorCursor` objects instead.:
 
-          >>> @gen.coroutine
-          ... def f():
-          ...     yield collection.insert_many([{'_id': i} for i in range(5)])
-          ...     cursor = collection.find().sort([('_id', 1)])
-          ...     while (yield cursor.fetch_next):
-          ...         doc = cursor.next_object()
-          ...         sys.stdout.write(str(doc['_id']) + ', ')
-          ...     print('done')
-          ...
-          >>> IOLoop.current().run_sync(f)
-          0, 1, 2, 3, 4, done
+           .. doctest:: fetch_next
+
+              >>> async def f():
+              ...     await collection.drop()
+              ...     await collection.insert_many([{'_id': i} for i in range(5)])
+              ...     async for doc in collection.find():
+              ...         sys.stdout.write(str(doc['_id']) + ', ')
+              ...     print('done')
+              ...
+              >>> IOLoop.current().run_sync(f)
+              0, 1, 2, 3, 4, done
 
         While it appears that fetch_next retrieves each document from
         the server individually, the cursor actually fetches documents
-        efficiently in `large batches`_.
-
-        In Python 3.5 and newer, cursors can be iterated elegantly and very
-        efficiently in native coroutines with `async for`:
+        efficiently in `large batches`_. Example usage:
 
         .. doctest:: fetch_next
 
-          >>> async def f():
-          ...     async for doc in collection.find():
-          ...         sys.stdout.write(str(doc['_id']) + ', ')
-          ...     print('done')
-          ...
-          >>> IOLoop.current().run_sync(f)
-          0, 1, 2, 3, 4, done
+           >>> async def f():
+           ...     await collection.drop()
+           ...     await collection.insert_many([{'_id': i} for i in range(5)])
+           ...     cursor = collection.find().sort([('_id', 1)])
+           ...     while (await cursor.fetch_next):
+           ...         doc = cursor.next_object()
+           ...         sys.stdout.write(str(doc['_id']) + ', ')
+           ...     print('done')
+           ...
+           >>> IOLoop.current().run_sync(f)
+           0, 1, 2, 3, 4, done
+
+        .. versionchanged:: 2.2
+           Deprecated.
 
         .. _`large batches`: https://docs.mongodb.com/manual/tutorial/iterate-a-cursor/#cursor-batches
+        .. _`gen.coroutine`: http://tornadoweb.org/en/stable/gen.html
         """
+        warnings.warn("The fetch_next property is deprecated and will be "
+                      "removed in Motor 3.0. Use `async for` to iterate "
+                      "over Cursor objects instead.",
+                      DeprecationWarning, stacklevel=2)
+
         if not self._buffer_size() and self.alive:
             # Return the Future, which resolves to number of docs fetched or 0.
             return self._get_more()
@@ -1136,9 +1200,21 @@ class AgnosticBaseCursor(AgnosticBase):
             return future
 
     def next_object(self):
-        """Get a document from the most recently fetched batch, or ``None``.
-        See :attr:`fetch_next`.
+        """**DEPRECATED** - Get a document from the most recently fetched
+        batch, or ``None``. See :attr:`fetch_next`.
+
+        The :meth:`next_object` method is deprecated and will be removed
+        in Motor 3.0. Use `async for` to elegantly iterate over
+        :class:`MotorCursor` objects instead.
+
+        .. versionchanged:: 2.2
+           Deprecated.
         """
+        warnings.warn("The next_object method is deprecated and will be "
+                      "removed in Motor 3.0. Use Use `async for` to iterate "
+                      "over Cursor objects instead.",
+                      DeprecationWarning, stacklevel=2)
+
         if not self._buffer_size():
             return None
         return next(self.delegate)
@@ -1155,34 +1231,33 @@ class AgnosticBaseCursor(AgnosticBase):
 
         .. testsetup:: each
 
-          from tornado.ioloop import IOLoop
-          MongoClient().test.test_collection.delete_many({})
-          MongoClient().test.test_collection.insert_many(
-              [{'_id': i} for i in range(5)])
+           from tornado.ioloop import IOLoop
+           MongoClient().test.test_collection.delete_many({})
+           MongoClient().test.test_collection.insert_many(
+               [{'_id': i} for i in range(5)])
 
-          collection = MotorClient().test.test_collection
+           collection = MotorClient().test.test_collection
 
         .. doctest:: each
 
-          >>> def each(result, error):
-          ...     if error:
-          ...         raise error
-          ...     elif result:
-          ...         sys.stdout.write(str(result['_id']) + ', ')
-          ...     else:
-          ...         # Iteration complete
-          ...         IOLoop.current().stop()
-          ...         print('done')
-          ...
-          >>> cursor = collection.find().sort([('_id', 1)])
-          >>> cursor.each(callback=each)
-          >>> IOLoop.current().start()
-          0, 1, 2, 3, 4, done
+           >>> def each(result, error):
+           ...     if error:
+           ...         raise error
+           ...     elif result:
+           ...         sys.stdout.write(str(result['_id']) + ', ')
+           ...     else:
+           ...         # Iteration complete
+           ...         IOLoop.current().stop()
+           ...         print('done')
+           ...
+           >>> cursor = collection.find().sort([('_id', 1)])
+           >>> cursor.each(callback=each)
+           >>> IOLoop.current().start()
+           0, 1, 2, 3, 4, done
 
         .. note:: Unlike other Motor methods, ``each`` requires a callback and
            does not return a Future, so it cannot be used in a coroutine.
-           ``async for``, :meth:`to_list`, :attr:`fetch_next` are much easier to
-           use.
+           ``async for`` and :meth:`to_list` are much easier to use.
 
         :Parameters:
          - `callback`: function taking (document, error)
@@ -1239,13 +1314,12 @@ class AgnosticBaseCursor(AgnosticBase):
           >>> from motor.motor_tornado import MotorClient
           >>> collection = MotorClient().test.test_collection
           >>>
-          >>> @gen.coroutine
-          ... def f():
+          >>> async def f():
           ...     cursor = collection.find().sort([('_id', 1)])
-          ...     docs = yield cursor.to_list(length=2)
+          ...     docs = await cursor.to_list(length=2)
           ...     while docs:
           ...         print(docs)
-          ...         docs = yield cursor.to_list(length=2)
+          ...         docs = await cursor.to_list(length=2)
           ...
           ...     print('done')
           ...
@@ -1296,6 +1370,9 @@ class AgnosticBaseCursor(AgnosticBase):
         # to_list_future will be the result of the user's to_list() call.
         try:
             result = get_more_result.result()
+            # Return early if the task was cancelled.
+            if future.done():
+                return
             collection = self.collection
             fix_outgoing = collection.database.delegate._fix_outgoing
 
@@ -1323,17 +1400,17 @@ class AgnosticBaseCursor(AgnosticBase):
     def get_io_loop(self):
         return self.collection.get_io_loop()
 
-    @motor_coroutine
-    def close(self):
-        """Explicitly kill this cursor on the server. Call like (in Tornado):
+    async def close(self):
+        """Explicitly kill this cursor on the server.
 
-        .. code-block:: python
+        Call like::
+
+            await cursor.close()
 
-            yield cursor.close()
         """
         if not self.closed:
             self.closed = True
-            yield self._framework.yieldable(self._close())
+            return self._close()
 
     def batch_size(self, batch_size):
         self.delegate.batch_size(batch_size)
@@ -1358,8 +1435,7 @@ class AgnosticBaseCursor(AgnosticBase):
     def _killed(self):
         raise NotImplementedError
 
-    @motor_coroutine
-    def _close(self):
+    async def _close(self):
         raise NotImplementedError()
 
 
@@ -1377,12 +1453,13 @@ class AgnosticCursor(AgnosticBaseCursor):
     max_scan          = MotorCursorChainingMethod()
     sort              = MotorCursorChainingMethod(doc=cursor_sort_doc)
     hint              = MotorCursorChainingMethod()
-    where             = MotorCursorChainingMethod()
+    where             = MotorCursorChainingMethod(doc=where_doc)
     max_await_time_ms = MotorCursorChainingMethod()
     max_time_ms       = MotorCursorChainingMethod()
     min               = MotorCursorChainingMethod()
     max               = MotorCursorChainingMethod()
     comment           = MotorCursorChainingMethod()
+    allow_disk_use    = MotorCursorChainingMethod()
 
     _Cursor__die  = AsyncRead()
 
@@ -1425,9 +1502,8 @@ class AgnosticCursor(AgnosticBaseCursor):
     def _killed(self):
         return self.delegate._Cursor__killed
 
-    @motor_coroutine
     def _close(self):
-        yield self._framework.yieldable(self._Cursor__die())
+        return self._Cursor__die()
 
 
 class AgnosticRawBatchCursor(AgnosticCursor):
@@ -1457,9 +1533,8 @@ class AgnosticCommandCursor(AgnosticBaseCursor):
     def _killed(self):
         return self.delegate._CommandCursor__killed
 
-    @motor_coroutine
     def _close(self):
-        yield self._framework.yieldable(self._CommandCursor__die())
+        return self._CommandCursor__die()
 
 
 class AgnosticRawBatchCommandCursor(AgnosticCommandCursor):
@@ -1475,6 +1550,9 @@ class _LatentCursor(object):
     _CommandCursor__killed = False
     cursor_id = None
 
+    def _CommandCursor__end_session(self, *args, **kwargs):
+        pass
+
     def _CommandCursor__die(self, *args, **kwargs):
         pass
 
@@ -1489,15 +1567,15 @@ class AgnosticLatentCommandCursor(AgnosticCommandCursor):
     __motor_class_name__ = 'MotorLatentCommandCursor'
 
     def __init__(self, collection, start, *args, **kwargs):
-        # We're being constructed without yield or await, like:
+        # We're being constructed without await, like:
         #
         #     cursor = collection.aggregate(pipeline)
         #
         # ... so we can't send the "aggregate" command to the server and get
         # a PyMongo CommandCursor back yet. Set self.delegate to a latent
-        # cursor until the first yield or await triggers _get_more(), which
+        # cursor until the first await triggers _get_more(), which
         # will execute the callback "start", which gets a PyMongo CommandCursor.
-        super(self.__class__, self).__init__(_LatentCursor(), collection)
+        super().__init__(_LatentCursor(), collection)
         self.start = start
         self.args = args
         self.kwargs = kwargs
@@ -1523,7 +1601,7 @@ class AgnosticLatentCommandCursor(AgnosticCommandCursor):
 
             return original_future
 
-        return super(self.__class__, self)._get_more()
+        return super()._get_more()
 
     def _on_started(self, original_future, future):
         try:
@@ -1536,13 +1614,16 @@ class AgnosticLatentCommandCursor(AgnosticCommandCursor):
             if not original_future.done():
                 original_future.set_exception(exc)
         else:
+            # Return early if the task was cancelled.
+            if original_future.done():
+                return
             if self.delegate._CommandCursor__data or not self.delegate.alive:
                 # _get_more is complete.
                 original_future.set_result(
                     len(self.delegate._CommandCursor__data))
             else:
                 # Send a getMore.
-                future = super(self.__class__, self)._get_more()
+                future = super()._get_more()
                 self._framework.chain_future(future, original_future)
 
 
@@ -1566,7 +1647,7 @@ class AgnosticChangeStream(AgnosticBase):
     def __init__(self, target, pipeline, full_document, resume_after,
                  max_await_time_ms, batch_size, collation,
                  start_at_operation_time, session, start_after):
-        super(self.__class__, self).__init__(delegate=None)
+        super().__init__(delegate=None)
         # The "target" object is a client, database, or collection.
         self._target = target
         self._kwargs = {'pipeline': pipeline,
@@ -1596,8 +1677,7 @@ class AgnosticChangeStream(AgnosticBase):
         self._lazy_init()
         return self.delegate.try_next()
 
-    @coroutine_annotation
-    def next(self):
+    async def next(self):
         """Advance the cursor.
 
         This method blocks until the next change document is returned or an
@@ -1636,10 +1716,9 @@ class AgnosticChangeStream(AgnosticBase):
         ``await change_stream.next()`` repeatedly.
         """
         loop = self.get_io_loop()
-        return self._framework.run_on_executor(loop, self._next)
+        return await self._framework.run_on_executor(loop, self._next)
 
-    @coroutine_annotation
-    def try_next(self):
+    async def try_next(self):
         """Advance the cursor without blocking indefinitely.
 
         This method returns the next change document without waiting
@@ -1674,36 +1753,30 @@ class AgnosticChangeStream(AgnosticBase):
         .. versionadded:: 2.1
         """
         loop = self.get_io_loop()
-        return self._framework.run_on_executor(loop, self._try_next)
+        return await self._framework.run_on_executor(loop, self._try_next)
 
-    @coroutine_annotation
-    def close(self):
+    async def close(self):
         """Close this change stream.
 
         Stops any "async for" loops using this change stream.
         """
         if self.delegate:
-            return self._close()
+            await self._close()
 
-        # Never started.
-        future = self._framework.get_future(self.get_io_loop())
-        future.set_result(None)
-        return future
+    def __aiter__(self):
+        return self
 
-    if PY35:
-        exec(textwrap.dedent("""
-        def __aiter__(self):
-            return self
+    __anext__ = next
 
-        __anext__ = next
+    async def __aenter__(self):
+        if not self.delegate:
+            loop = self.get_io_loop()
+            await self._framework.run_on_executor(loop, self._lazy_init)
+        return self
 
-        async def __aenter__(self):
-            return self
-    
-        async def __aexit__(self, exc_type, exc_val, exc_tb):
-            if self.delegate:
-                self.delegate.close() 
-        """), globals(), locals())
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        if self.delegate:
+            await self.close()
 
     def get_io_loop(self):
         return self._target.get_io_loop()
