@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals
-
 
 get_database_doc = """
 Get a :class:`MotorDatabase` with the given name and options.
@@ -94,7 +92,7 @@ based only on the URI in a configuration file.
    Removed this method.
 """
 
-fsync_doc = """Flush all pending writes to datafiles.
+fsync_doc = """**DEPRECATED**: Flush all pending writes to datafiles.
 
 Optional parameters can be passed as keyword arguments:
   - `lock`: If True lock the server to disallow writes.
@@ -110,14 +108,24 @@ Optional parameters can be passed as keyword arguments:
     options = {'async': True}
     await client.fsync(**options)
 
+Deprecated. Run the `fsync command`_ directly with
+:meth:`~motor.motor_tornado.MotorDatabase.command` instead. For example::
+
+    await client.admin.command('fsync', lock=True)
+
+.. versionchanged:: 2.2
+   Deprecated.
+
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 
 .. warning:: `async` and `lock` can not be used together.
 
 .. warning:: MongoDB does not support the `async` option
              on Windows and will raise an exception on that
              platform.
+
+.. _fsync command: https://docs.mongodb.com/manual/reference/command/fsync/
 """
 
 current_op_doc = """
@@ -299,17 +307,17 @@ command document before it is sent.
 For example, a command like ``{buildinfo: 1}`` can be sent
 using::
 
-    result = yield db.command("buildinfo")
+    result = await db.command("buildinfo")
 
 For a command where the value matters, like ``{collstats:
 collection_name}`` we can do::
 
-    result = yield db.command("collstats", collection_name)
+    result = await db.command("collstats", collection_name)
 
 For commands that take additional arguments we can use
 kwargs. So ``{filemd5: object_id, root: file_root}`` becomes::
 
-    result = yield db.command("filemd5", object_id, root=file_root)
+    result = await db.command("filemd5", object_id, root=file_root)
 
 :Parameters:
   - `command`: document representing the command to be issued,
@@ -356,6 +364,10 @@ This deletes all matching documents and prints "3".
   - `collation` (optional): An instance of
     :class:`~pymongo.collation.Collation`. This option is only supported
     on MongoDB 3.4 and above.
+  - `hint` (optional): An index used to support the query predicate specified
+    either by its string name, or in the same format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.4 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -363,8 +375,10 @@ This deletes all matching documents and prints "3".
 :Returns:
   - An instance of :class:`~pymongo.results.DeleteResult`.
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 """
 
 delete_one_doc = """Delete a single document matching the filter.
@@ -382,6 +396,10 @@ This deletes one matching document and prints "1".
   - `collation` (optional): An instance of
     :class:`~pymongo.collation.Collation`. This option is only supported
     on MongoDB 3.4 and above.
+  - `hint` (optional): An index used to support the query predicate specified
+    either by its string name, or in the same format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.4 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -389,8 +407,10 @@ This deletes one matching document and prints "1".
 :Returns:
   - An instance of :class:`~pymongo.results.DeleteResult`.
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 """
 
 drop_doc = """Alias for ``drop_collection``.
@@ -401,47 +421,6 @@ The following two calls are equivalent::
   await db.drop_collection("foo")
 """
 
-
-exists_doc = """Check if a file exists.
-
-The file to check for can be specified by the value of its
-``_id`` key, or by passing in a query document. A query
-document can be passed in as dictionary, or by using keyword
-arguments. Thus, the following three calls are equivalent::
-
-  await fs.exists(file_id)
-  await fs.exists({"_id": file_id})
-  await fs.exists(_id=file_id)
-
-As are the following two calls::
-
-  await fs.exists({"filename": "mike.txt"})
-  await fs.exists(filename="mike.txt")
-
-And the following two::
-
-  await fs.exists({"foo": {"$gt": 12}})
-  await fs.exists(foo={"$gt": 12})
-
-Returns ``True`` if a matching file exists, ``False``
-otherwise. Calls to :meth:`exists` will not automatically
-create appropriate indexes; application developers should be
-sure to create indexes if needed and as appropriate.
-
-:Parameters:
-  - `document_or_id` (optional): query document, or _id of the
-    document to check for
-  - `session` (optional): a
-    :class:`~pymongo.client_session.ClientSession`, created with
-    :meth:`~MotorClient.start_session`.
-  - `**kwargs` (optional): keyword arguments are used as a
-    query document, if they're present.
-
-.. versionchanged:: 1.2
-   Added session parameter.
-"""
-
-
 find_one_doc = """Get a single document from the database.
 
 All arguments to :meth:`find` are also valid arguments for
@@ -526,6 +505,10 @@ This prints::
   - `sort` (optional): a list of (key, direction) pairs
     specifying the sort order for the query. If multiple documents
     match the query, they are sorted and the first is deleted.
+  - `hint` (optional): An index used to support the query predicate specified
+    either by its string name, or in the same format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.4 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -538,8 +521,10 @@ This command uses the :class:`~pymongo.write_concern.WriteConcern` of this
 that using an elevated write concern with this command may be slower compared
 to using the default write concern.
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 """
 
 find_one_and_replace_doc = """Finds a single document and replaces it, returning
@@ -591,6 +576,11 @@ This will print::
     if no document matches. If
     :attr:`ReturnDocument.AFTER`, returns the replaced
     or inserted document.
+  - `hint` (optional): An index to use to support the query
+    predicate specified either by its string name, or in the same
+    format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.4 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -603,11 +593,12 @@ This command uses the :class:`~pymongo.write_concern.WriteConcern` of this
 that using an elevated write concern with this command may be slower compared
 to using the default write concern.
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 """
 
-
 find_one_and_update_doc = """Finds a single document and updates it, returning
 either the original or the updated document. By default
 :meth:`find_one_and_update` returns the original version of
@@ -703,6 +694,11 @@ This would print::
     or inserted document.
   - `array_filters` (optional): A list of filters specifying which
     array elements an update should apply. Requires MongoDB 3.6+.
+  - `hint` (optional): An index to use to support the query
+    predicate specified either by its string name, or in the same
+    format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.4 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -716,8 +712,10 @@ This command uses the
 3.2. Note that using an elevated write concern with this command may
 be slower compared to using the default write concern.
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added array_filters and session parameters.
+   Added ``array_filters`` and ``session`` parameters.
 """
 
 index_information_doc = """Get information on this collection's indexes.
@@ -781,7 +779,6 @@ This prints something like::
    Added session parameter.
 """
 
-
 insert_one_doc = """Insert a single document. ::
 
   async def insert_x():
@@ -815,7 +812,6 @@ This code outputs the new document's ``_id``::
    Added session parameter.
 """
 
-
 mr_doc = """Perform a map/reduce operation on this collection.
 
 If `full_response` is ``False`` (default) returns a
@@ -840,7 +836,7 @@ response from the server to the `map reduce command`_.
     `map reduce command`_ may be passed as keyword arguments to this
     helper method, e.g.::
 
-       result = yield db.test.map_reduce(map, reduce, "myresults", limit=2)
+       result = await db.test.map_reduce(map, reduce, "myresults", limit=2)
 
 Returns a Future.
 
@@ -857,7 +853,6 @@ Returns a Future.
    Added session parameter.
 """
 
-
 replace_one_doc = """Replace a single document matching the filter.
 
 Say our collection has one document::
@@ -910,6 +905,11 @@ This prints::
   - `collation` (optional): An instance of
     :class:`~pymongo.collation.Collation`. This option is only supported
     on MongoDB 3.4 and above.
+  - `hint` (optional): An index to use to support the query
+    predicate specified either by its string name, or in the same
+    format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.2 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -920,17 +920,12 @@ This prints::
 .. note:: `bypass_document_validation` requires server version
   **>= 3.2**
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added session parameter.
+   Added ``session`` parameter.
 """
 
-
-update_doc = """Update a document(s) in this collection.
-
-**DEPRECATED** - Use :meth:`replace_one`, :meth:`update_one`, or
-:meth:`update_many` instead."""
-
-
 update_many_doc = """Update one or more documents that match the filter.
 
 Say our collection has 3 documents::
@@ -971,6 +966,11 @@ This prints::
     on MongoDB 3.4 and above.
   - `array_filters` (optional): A list of filters specifying which
     array elements an update should apply. Requires MongoDB 3.6+.
+  - `hint` (optional): An index to use to support the query
+    predicate specified either by its string name, or in the same
+    format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.2 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -981,11 +981,12 @@ This prints::
 .. note:: `bypass_document_validation` requires server version
   **>= 3.2**
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added array_filters and session parameters.
+   Added ``array_filters`` and ``session`` parameters.
 """
 
-
 update_one_doc = """Update a single document matching the filter.
 
 Say our collection has 3 documents::
@@ -1026,6 +1027,11 @@ This prints::
     on MongoDB 3.4 and above.
   - `array_filters` (optional): A list of filters specifying which
     array elements an update should apply. Requires MongoDB 3.6+.
+  - `hint` (optional): An index to use to support the query
+    predicate specified either by its string name, or in the same
+    format as passed to
+    :meth:`~MotorDatabase.create_index` (e.g. ``[('field', ASCENDING)]``).
+    This option is only supported on MongoDB 4.2 and above.
   - `session` (optional): a
     :class:`~pymongo.client_session.ClientSession`, created with
     :meth:`~MotorClient.start_session`.
@@ -1036,11 +1042,12 @@ This prints::
 .. note:: `bypass_document_validation` requires server version
   **>= 3.2**
 
+.. versionchanged:: 2.2
+   Added ``hint`` parameter.
 .. versionchanged:: 1.2
-   Added array_filters and session parameters.
+   Added ``array_filters`` and ``session`` parameters.
 """
 
-
 cursor_sort_doc = """Sorts this cursor's results.
 
 Pass a field name and a direction, either
@@ -1056,10 +1063,9 @@ Pass a field name and a direction, either
 
 .. doctest:: sort
 
-  >>> @gen.coroutine
-  ... def f():
+  >>> async def f():
   ...     cursor = collection.find().sort('_id', pymongo.DESCENDING)
-  ...     docs = yield cursor.to_list(None)
+  ...     docs = await cursor.to_list(None)
   ...     print([d['_id'] for d in docs])
   ...
   >>> IOLoop.current().run_sync(f)
@@ -1069,13 +1075,12 @@ To sort by multiple fields, pass a list of (key, direction) pairs:
 
 .. doctest:: sort
 
-  >>> @gen.coroutine
-  ... def f():
+  >>> async def f():
   ...     cursor = collection.find().sort([
   ...         ('field1', pymongo.ASCENDING),
   ...         ('field2', pymongo.DESCENDING)])
   ...
-  ...     docs = yield cursor.to_list(None)
+  ...     docs = await cursor.to_list(None)
   ...     print([(d['field1'], d['field2']) for d in docs])
   ...
   >>> IOLoop.current().run_sync(f)
@@ -1095,16 +1100,14 @@ Text search results can be sorted by relevance:
 
 .. doctest:: sort_text
 
-  >>> @gen.coroutine
-  ... def f():
+  >>> async def f():
   ...     cursor = collection.find({
   ...         '$text': {'$search': 'some words'}},
   ...         {'score': {'$meta': 'textScore'}})
   ...
   ...     # Sort by 'score' field.
   ...     cursor.sort([('score', {'$meta': 'textScore'})])
-  ...     docs = yield cursor.to_list(None)
-  ...     for doc in docs:
+  ...     async for doc in cursor:
   ...         print('%.1f %s' % (doc['score'], doc['field']))
   ...
   >>> IOLoop.current().run_sync(f)
@@ -1122,7 +1125,6 @@ cursor has any effect.
     key, if not given :data:`~pymongo.ASCENDING` is assumed
 """
 
-
 start_session_doc = """Start a logical session.
 
 This method takes the same parameters as PyMongo's
@@ -1191,87 +1193,78 @@ started it.
 .. versionadded:: 1.2
 """
 
-
-with_transaction_doc = """Executes an awaitable in a transaction.
-
-This method starts a transaction on this session, awaits ``coro``
-once, and then commits the transaction. For example::
-
-  async def coro(session):
-      orders = session.client.db.orders
-      inventory = session.client.db.inventory
-      inserted_id = await orders.insert_one(
-          {"sku": "abc123", "qty": 100}, session=session)
-      await inventory.update_one(
-          {"sku": "abc123", "qty": {"$gte": 100}},
-          {"$inc": {"qty": -100}}, session=session)
-      return inserted_id
-
-  async with await client.start_session() as session:
-      inserted_id = await session.with_transaction(coro)
-
-To pass arbitrary arguments to the ``coro``, wrap it with a
-``lambda`` like this::
-
-  async def coro(session, custom_arg, custom_kwarg=None):
-      # Transaction operations...
-
-  async with await client.start_session() as session:
-      await session.with_transaction(
-          lambda s: coro(s, "custom_arg", custom_kwarg=1))
-
-In the event of an exception, ``with_transaction`` may retry the commit
-or the entire transaction, therefore ``coro`` may be awaited
-multiple times by a single call to ``with_transaction``. Developers
-should be mindful of this possiblity when writing a ``coro`` that
-modifies application state or has any other side-effects.
-Note that even when the ``coro`` is invoked multiple times,
-``with_transaction`` ensures that the transaction will be committed
-at-most-once on the server.
-
-The ``coro`` should not attempt to start new transactions, but
-should simply run operations meant to be contained within a
-transaction. The ``coro`` should also not commit the transaction;
-this is handled automatically by ``with_transaction``. If the
-``coro`` does commit or abort the transaction without error,
-however, ``with_transaction`` will return without taking further
-action.
-
-When ``coro`` raises an exception, ``with_transaction``
-automatically aborts the current transaction. When ``coro`` or
-:meth:`~ClientSession.commit_transaction` raises an exception that
-includes the ``"TransientTransactionError"`` error label,
-``with_transaction`` starts a new transaction and re-executes
-the ``coro``.
-
-When :meth:`~ClientSession.commit_transaction` raises an exception with
-the ``"UnknownTransactionCommitResult"`` error label,
-``with_transaction`` retries the commit until the result of the
-transaction is known.
-
-This method will cease retrying after 120 seconds has elapsed. This
-timeout is not configurable and any exception raised by the
-``coro`` or by :meth:`ClientSession.commit_transaction` after the
-timeout is reached will be re-raised. Applications that desire a
-different timeout duration should not use this method.
+unlock_doc = """**DEPRECATED**: Unlock a previously locked server.
 
 :Parameters:
-  - `coro`: The coroutine to run inside a transaction. The coroutine must
-    accept a single argument, this session. Note, under certain error
-    conditions the coroutine may be run multiple times.
-  - `read_concern` (optional): The
-    :class:`~pymongo.read_concern.ReadConcern` to use for this
-    transaction.
-  - `write_concern` (optional): The
-    :class:`~pymongo.write_concern.WriteConcern` to use for this
-    transaction.
-  - `read_preference` (optional): The read preference to use for this
-    transaction. If ``None`` (the default) the :attr:`read_preference`
-    of this :class:`Database` is used. See
-    :mod:`~pymongo.read_preferences` for options.
+  - `session` (optional): a
+    :class:`~motor.motor_tornado.MotorClientSession`.
 
-:Returns:
-  The return value of the ``coro``.
+Deprecated. Users of MongoDB version 3.2 or newer can run the
+`fsyncUnlock command`_ directly with
+:meth:`~motor.motor_tornado.MotorDatabase.command`::
 
-.. versionadded:: 3.9
+     await motor_client.admin.command('fsyncUnlock')
+
+Users of MongoDB version 3.0 can query the "unlock" virtual
+collection::
+
+    await motor_client.admin["$cmd.sys.unlock"].find_one()
+
+.. versionchanged:: 2.2
+   Deprecated.
+
+.. _fsyncUnlock command: https://docs.mongodb.com/manual/reference/command/fsyncUnlock/
+"""
+
+reindex_doc = """**DEPRECATED**: Rebuild all indexes on this collection.
+
+Deprecated. Use :meth:`~motor.motor_tornado.MotorDatabase.command`
+to run the ``reIndex`` command directly instead::
+
+  await db.command({"reIndex": "<collection_name>"})
+
+.. note:: Starting in MongoDB 4.6, the `reIndex` command can only be
+  run when connected to a standalone mongod.
+
+:Parameters:
+  - `session` (optional): a
+    :class:`~motor.motor_tornado.MotorClientSession`.
+  - `**kwargs` (optional): optional arguments to the reIndex
+    command (like maxTimeMS) can be passed as keyword arguments.
+
+.. warning:: reindex blocks all other operations (indexes
+   are built in the foreground) and will be slow for large
+   collections.
+
+.. versionchanged:: 2.2
+   Deprecated.
+"""
+
+where_doc = """Adds a `$where`_ clause to this query.
+
+The `code` argument must be an instance of :class:`str`
+:class:`~bson.code.Code` containing a JavaScript expression.
+This expression will be evaluated for each document scanned.
+Only those documents for which the expression evaluates to *true*
+will be returned as results. The keyword *this* refers to the object
+currently being scanned. For example::
+
+    # Find all documents where field "a" is less than "b" plus "c".
+    async for doc in db.test.find().where('this.a < (this.b + this.c)'):
+        print(doc)
+
+Raises :class:`TypeError` if `code` is not an instance of
+:class:`str`. Raises :class:`~pymongo.errors.InvalidOperation`
+if this :class:`~motor.motor_tornado.MotorCursor` has already been used.
+Only the last call to :meth:`where` applied to a
+:class:`~motor.motor_tornado.MotorCursor` has any effect.
+
+.. note:: MongoDB 4.4 drops support for :class:`~bson.code.Code`
+  with scope variables. Consider using `$expr`_ instead.
+
+:Parameters:
+  - `code`: JavaScript expression to use as a filter
+
+.. _$expr: https://docs.mongodb.com/manual/reference/operator/query/expr/
+.. _$where: https://docs.mongodb.com/manual/reference/operator/query/where/
 """
