@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, absolute_import
-
 """Dynamic class-creation for Motor."""
 
 import inspect
@@ -113,25 +111,10 @@ def unwrap_kwargs_session(kwargs):
 _coro_token = object()
 
 
-def motor_coroutine(f):
-    """Used by Motor classes to mark functions as coroutines.
-
-    create_class_with_framework will decorate the function with a framework-
-    specific coroutine decorator, like asyncio.coroutine or Tornado's
-    gen.coroutine.
-
-    You cannot return a value from a motor_coroutine, the syntax differences
-    between Tornado on Python 2 and asyncio with Python 3.5 are impossible to
-    bridge.
-    """
-    f._is_motor_coroutine = _coro_token
-    return f
-
-
 def coroutine_annotation(f):
     """In docs, annotate a function that returns a Future with 'coroutine'.
 
-    Unlike @motor_coroutine, this doesn't affect behavior.
+    This doesn't affect behavior.
     """
     # Like:
     # @coroutine_annotation
@@ -162,7 +145,7 @@ class Async(MotorAttributeFactory):
          - `attr_name`: The name of the attribute on the PyMongo class, if
            different from attribute on the Motor class
         """
-        super(Async, self).__init__(doc)
+        super().__init__(doc)
         self.attr_name = attr_name
         self.wrap_class = None
         self.unwrap_class = None
@@ -288,14 +271,7 @@ def create_class_with_framework(cls, framework, module_name):
     if cached_class:
         return cached_class
 
-    # Remove the special __dict__ proxy and let type() create it instead,
-    # otherwise attempting to access cls().__dict__ will raise a TypeError:
-    # TypeError: descriptor '__dict__' for 'AgnosticGridIn' objects doesn't
-    # apply to 'MotorGridIn' object.
-    cls_dict = dict(cls.__dict__)
-    cls_dict.pop('__dict__', None)
-
-    new_class = type(str(motor_class_name), cls.__bases__, cls_dict)
+    new_class = type(str(motor_class_name), (cls,), {})
     new_class.__module__ = module_name
     new_class._framework = framework
 
@@ -312,11 +288,5 @@ def create_class_with_framework(cls, framework, module_name):
                 new_class_attr = attr.create_attribute(new_class, name)
                 setattr(new_class, name, new_class_attr)
 
-            elif getattr(attr, '_is_motor_coroutine', None) is _coro_token:
-                coro = framework.coroutine(attr)
-                del coro._is_motor_coroutine
-                coro.coroutine_annotation = True
-                setattr(new_class, name, coro)
-
     _class_cache[cache_key] = new_class
     return new_class
