@@ -12,11 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, absolute_import
-
 """GridFS implementation for Motor, an asynchronous driver for MongoDB."""
 
-import textwrap
 import warnings
 
 import gridfs
@@ -25,53 +22,29 @@ import pymongo.errors
 from gridfs import (DEFAULT_CHUNK_SIZE,
                     grid_file)
 
-from motor.core import (AgnosticBaseCursor,
+from motor.core import (AgnosticCursor,
                         AgnosticCollection,
-                        AgnosticDatabase,
-                        PY35)
+                        AgnosticDatabase)
 from motor.docstrings import *
 from motor.metaprogramming import (AsyncCommand,
                                    AsyncRead,
                                    coroutine_annotation,
                                    create_class_with_framework,
                                    DelegateMethod,
-                                   motor_coroutine,
                                    MotorCursorChainingMethod,
                                    ReadOnlyProperty)
 
 
-class AgnosticGridOutCursor(AgnosticBaseCursor):
+class AgnosticGridOutCursor(AgnosticCursor):
     __motor_class_name__ = 'MotorGridOutCursor'
     __delegate_class__ = gridfs.GridOutCursor
 
-    add_option        = MotorCursorChainingMethod()
-    address           = ReadOnlyProperty()
-    collation         = ReadOnlyProperty()
-    comment           = MotorCursorChainingMethod()
-    distinct          = AsyncRead()
-    explain           = AsyncRead()
-    hint              = MotorCursorChainingMethod()
-    limit             = MotorCursorChainingMethod()
-    max               = MotorCursorChainingMethod()
-    max_await_time_ms = MotorCursorChainingMethod()
-    max_scan          = MotorCursorChainingMethod()
-    max_time_ms       = MotorCursorChainingMethod()
-    min               = MotorCursorChainingMethod()
-    remove_option     = MotorCursorChainingMethod()
-    skip              = MotorCursorChainingMethod()
-    sort              = MotorCursorChainingMethod(doc=cursor_sort_doc)
-    where             = MotorCursorChainingMethod()
-
     # PyMongo's GridOutCursor inherits __die from Cursor.
     _Cursor__die = AsyncCommand()
 
-    def clone(self):
-        """Get a clone of this cursor."""
-        return self.__class__(self.delegate.clone(), self.collection)
-
     def next_object(self):
-        """Get next GridOut object from cursor."""
-        grid_out = super(self.__class__, self).next_object()
+        """**DEPRECATED** - Get next GridOut object from cursor."""
+        grid_out = super().next_object()
         if grid_out:
             grid_out_class = create_class_with_framework(
                 AgnosticGridOut, self._framework, self.__module__)
@@ -81,35 +54,10 @@ class AgnosticGridOutCursor(AgnosticBaseCursor):
             # Exhausted.
             return None
 
-    def rewind(self):
-        """Rewind this cursor to its unevaluated state."""
-        self.delegate.rewind()
-        self.started = False
-        return self
-
-    def _empty(self):
-        return self.delegate._Cursor__empty
-
-    def _query_flags(self):
-        return self.delegate._Cursor__query_flags
-
-    def _data(self):
-        return self.delegate._Cursor__data
-
-    def _clear_cursor_id(self):
-        self.delegate._Cursor__id = 0
-
     def _close_exhaust_cursor(self):
         # Exhaust MotorGridOutCursors are prohibited.
         pass
 
-    def _killed(self):
-        return self.delegate._Cursor__killed
-
-    @motor_coroutine
-    def _close(self):
-        yield self._framework.yieldable(self._Cursor__die())
-
 
 class MotorGridOutProperty(ReadOnlyProperty):
     """Creates a readonly attribute on the wrapped PyMongo GridOut."""
@@ -183,18 +131,14 @@ class AgnosticGridOut(object):
 
         self.io_loop = root_collection.get_io_loop()
 
-    # python.org/dev/peps/pep-0492/#api-design-and-implementation-revisions
-    if PY35:
-        exec(textwrap.dedent("""
-        def __aiter__(self):
-            return self
+    def __aiter__(self):
+        return self
 
-        async def __anext__(self):
-            chunk = await self.readchunk()
-            if chunk:
-                return chunk
-            raise StopAsyncIteration()
-        """), globals(), locals())
+    async def __anext__(self):
+        chunk = await self.readchunk()
+        if chunk:
+            return chunk
+        raise StopAsyncIteration()
 
     def __getattr__(self, item):
         if not self.delegate._file:
@@ -224,8 +168,7 @@ class AgnosticGridOut(object):
     def get_io_loop(self):
         return self.io_loop
 
-    @motor_coroutine
-    def stream_to_handler(self, request_handler):
+    async def stream_to_handler(self, request_handler):
         """Write the contents of this file to a
         :class:`tornado.web.RequestHandler`. This method calls
         :meth:`~tornado.web.RequestHandler.flush` on
@@ -240,15 +183,15 @@ class AgnosticGridOut(object):
                 @gen.coroutine
                 def get(self, filename):
                     db = self.settings['db']
-                    fs = yield motor.MotorGridFSBucket(db())
+                    fs = await motor.MotorGridFSBucket(db())
                     try:
-                        gridout = yield fs.open_download_stream_by_name(filename)
+                        gridout = await fs.open_download_stream_by_name(filename)
                     except gridfs.NoFile:
                         raise tornado.web.HTTPError(404)
 
                     self.set_header("Content-Type", gridout.content_type)
                     self.set_header("Content-Length", gridout.length)
-                    yield gridout.stream_to_handler(self)
+                    await gridout.stream_to_handler(self)
                     self.finish()
 
         .. seealso:: Tornado `RequestHandler <http://tornadoweb.org/en/stable/web.html#request-handlers>`_
@@ -256,9 +199,7 @@ class AgnosticGridOut(object):
         written = 0
         while written < self.length:
             # Reading chunk_size at a time minimizes buffering.
-            f = self._framework.yieldable(self.read(self.chunk_size))
-            yield f
-            chunk = f.result()
+            chunk = await self.read(self.chunk_size)
 
             # write() simply appends the output to a list; flush() sends it
             # over the network and minimizes buffering in the handler.
@@ -368,15 +309,12 @@ Metadata set on the file appears as attributes on a
                 disable_md5=disable_md5,
                 **kwargs)
 
-    if PY35:
-        # Support "async with bucket.open_upload_stream() as f:"
-        exec(textwrap.dedent("""
-        async def __aenter__(self):
-            return self
+    # Support "async with bucket.open_upload_stream() as f:"
+    async def __aenter__(self):
+        return self
 
-        async def __aexit__(self, exc_type, exc_val, exc_tb):
-            await self.close()
-        """), globals(), locals())
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        await self.close()
 
     def get_io_loop(self):
         return self.io_loop
@@ -500,9 +438,9 @@ class AgnosticGridFSBucket(object):
         For example::
 
           cursor = bucket.find({"filename": "lisa.txt"}, no_cursor_timeout=True)
-          while (yield cursor.fetch_next):
+          while (await cursor.fetch_next):
               grid_out = cursor.next_object()
-              data = yield grid_out.read()
+              data = await grid_out.read()
 
         This iterates through all versions of "lisa.txt" stored in GridFS.
         Note that setting no_cursor_timeout to True may be important to
