@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals
-
 """Test Motor, an asynchronous driver for MongoDB and Tornado."""
 
 import logging
@@ -57,7 +55,7 @@ class SkippedModule(object):
 
 class MotorTestLoader(unittest.TestLoader):
     def __init__(self, avoid=None, reason=None):
-        super(MotorTestLoader, self).__init__()
+        super().__init__()
         self._avoid = []
 
     def avoid(self, *prefixes, **kwargs):
@@ -77,7 +75,7 @@ class MotorTestLoader(unittest.TestLoader):
             if name.startswith(prefix):
                 return SkippedModule(name, reason)
 
-        return super(MotorTestLoader, self)._get_module_from_name(name)
+        return super()._get_module_from_name(name)
 
 
 class MockRequestHandler(object):
