@@ -46,7 +46,11 @@ class _TestMethodWrapper(object):
 
     def __call__(self):
         result = self.orig_method()
-        if inspect.isgenerator(result):
+        if inspect.iscoroutine(result):
+            # Cancel the undecorated task to avoid this warning:
+            # RuntimeWarning: coroutine 'test_foo' was never awaited
+            task = ensure_future(result)
+            task.cancel()
             raise TypeError("Generator test methods should be decorated with "
                             "@asyncio_test")
         elif result is not None:
@@ -78,7 +82,7 @@ class AsyncIOTestCase(AssertLogsMixin, unittest.TestCase):
             getattr(self, methodName)))
 
     def setUp(self):
-        super(AsyncIOTestCase, self).setUp()
+        super().setUp()
 
         # Ensure that the event loop is passed explicitly in Motor.
         asyncio.set_event_loop(None)
@@ -95,10 +99,10 @@ class AsyncIOTestCase(AssertLogsMixin, unittest.TestCase):
 
     def get_client_kwargs(self, **kwargs):
         if env.mongod_started_with_ssl:
-            kwargs.setdefault('ssl_ca_certs', CA_PEM)
-            kwargs.setdefault('ssl_certfile', CLIENT_PEM)
+            kwargs.setdefault('tlsCAFile', CA_PEM)
+            kwargs.setdefault('tlsCertificateKeyFile', CLIENT_PEM)
 
-        kwargs.setdefault('ssl', env.mongod_started_with_ssl)
+        kwargs.setdefault('tls', env.mongod_started_with_ssl)
         kwargs.setdefault('io_loop', self.loop)
 
         return kwargs
@@ -123,10 +127,9 @@ class AsyncIOTestCase(AssertLogsMixin, unittest.TestCase):
             *args,
             **self.get_client_kwargs(**kwargs))
 
-    @asyncio.coroutine
-    def make_test_data(self):
-        yield from self.collection.delete_many({})
-        yield from self.collection.insert_many([{'_id': i} for i in range(200)])
+    async def make_test_data(self):
+        await self.collection.delete_many({})
+        await self.collection.insert_many([{'_id': i} for i in range(200)])
 
     make_test_data.__test__ = False
 
@@ -156,15 +159,11 @@ class AsyncIOMockServerTestCase(AsyncIOTestCase):
         return self.loop.run_in_executor(None,
                                          functools.partial(fn, *args, **kwargs))
 
-    def ensure_future(self, coro):
-        return ensure_future(coro, loop=self.loop)
-
     def fetch_next(self, cursor):
-        @asyncio.coroutine
-        def fetch_next():
-            return (yield from cursor.fetch_next)
+        async def fetch_next():
+            return await cursor.fetch_next
 
-        return self.ensure_future(fetch_next())
+        return ensure_future(fetch_next())
 
 
 # TODO: Spin off to a PyPI package.
@@ -201,14 +200,14 @@ def asyncio_test(func=None, timeout=None):
 
             def exc_handler(loop, context):
                 nonlocal coro_exc
-                coro_exc = context['exception']
+                # Exception is optional.
+                coro_exc = context.get('exception', Exception(context))
 
                 # Raise CancelledError from run_until_complete below.
                 task.cancel()
 
             self.loop.set_exception_handler(exc_handler)
-            coro = asyncio.coroutine(f)(self, *args, **kwargs)
-            coro = asyncio.wait_for(coro, actual_timeout, loop=self.loop)
+            coro = asyncio.wait_for(f(self, *args, **kwargs), actual_timeout)
             task = ensure_future(coro, loop=self.loop)
             try:
                 self.loop.run_until_complete(task)
@@ -238,26 +237,22 @@ def asyncio_test(func=None, timeout=None):
         return wrap
 
 
-@asyncio.coroutine
-def get_command_line(client):
-    command_line = yield from client.admin.command('getCmdLineOpts')
+async def get_command_line(client):
+    command_line = await client.admin.command('getCmdLineOpts')
     assert command_line['ok'] == 1, "getCmdLineOpts() failed"
     return command_line
 
 
-@asyncio.coroutine
-def server_is_mongos(client):
-    ismaster_response = yield from client.admin.command('ismaster')
+async def server_is_mongos(client):
+    ismaster_response = await client.admin.command('ismaster')
     return ismaster_response.get('msg') == 'isdbgrid'
 
 
-@asyncio.coroutine
-def skip_if_mongos(client):
-    is_mongos = yield from server_is_mongos(client)
+async def skip_if_mongos(client):
+    is_mongos = await server_is_mongos(client)
     if is_mongos:
         raise unittest.SkipTest("connected to mongos")
 
 
-@asyncio.coroutine
-def remove_all_users(db):
-    yield from db.command({"dropAllUsersFromDatabase": 1})
+async def remove_all_users(db):
+    await db.command({"dropAllUsersFromDatabase": 1})
