@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, absolute_import
-
 from unittest import SkipTest
 
 import pymongo
@@ -38,12 +36,12 @@ class AIOMotorTestBasic(AsyncIOTestCase):
         self.assertTrue(repr(cursor).startswith('AsyncIOMotorCursor'))
 
     @asyncio_test
-    def test_write_concern(self):
+    async def test_write_concern(self):
         # Default empty dict means "w=1"
         self.assertEqual(WriteConcern(), self.cx.write_concern)
 
-        yield from self.collection.delete_many({})
-        yield from self.collection.insert_one({'_id': 0})
+        await self.collection.delete_many({})
+        await self.collection.insert_one({'_id': 0})
 
         for gle_options in [
             {},
@@ -63,18 +61,18 @@ class AIOMotorTestBasic(AsyncIOTestCase):
 
             if wc.acknowledged:
                 with self.assertRaises(pymongo.errors.DuplicateKeyError):
-                    yield from collection.insert_one({'_id': 0})
+                    await collection.insert_one({'_id': 0})
             else:
-                yield from collection.insert_one({'_id': 0})  # No error
+                await collection.insert_one({'_id': 0})  # No error
 
             # No error
             c = collection.with_options(write_concern=WriteConcern(w=0))
-            yield from c.insert_one({'_id': 0})
+            await c.insert_one({'_id': 0})
             cx.close()
 
     @ignore_deprecations
     @asyncio_test
-    def test_read_preference(self):
+    async def test_read_preference(self):
         # Check the default
         cx = motor_asyncio.AsyncIOMotorClient(test.env.uri, io_loop=self.loop)
         self.assertEqual(ReadPreference.PRIMARY, cx.read_preference)
@@ -132,3 +130,26 @@ class AIOMotorTestBasic(AsyncIOTestCase):
         # MOTOR-104, TypeError: Can't instantiate abstract class C with abstract
         # methods collection, db, subcollection.
         C()
+
+    @asyncio_test
+    async def test_inheritance(self):
+        class CollectionSubclass(motor_asyncio.AsyncIOMotorCollection):
+            pass
+
+        class DatabaseSubclass(motor_asyncio.AsyncIOMotorDatabase):
+            def __getitem__(self, name):
+                return CollectionSubclass(self, name)
+
+        class ClientSubclass(motor_asyncio.AsyncIOMotorClient):
+            def __getitem__(self, name):
+                return DatabaseSubclass(self, name)
+
+        cx = ClientSubclass(test.env.uri, **self.get_client_kwargs())
+        self.assertIsInstance(cx, ClientSubclass)
+
+        db = cx['testdb']
+        self.assertIsInstance(db, DatabaseSubclass)
+
+        coll = db['testcoll']
+        self.assertIsInstance(coll, CollectionSubclass)
+        self.assertIsNotNone(await coll.insert_one({}))
