@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, absolute_import
-
 """Test Motor, an asynchronous driver for MongoDB and Tornado."""
 
 import pymongo
@@ -38,12 +36,12 @@ class MotorTestBasic(MotorTest):
         self.assertTrue(repr(cursor).startswith('MotorCursor'))
 
     @gen_test
-    def test_write_concern(self):
+    async def test_write_concern(self):
         # Default empty dict means "w=1"
         self.assertEqual(WriteConcern(), self.cx.write_concern)
 
-        yield self.collection.delete_many({})
-        yield self.collection.insert_one({'_id': 0})
+        await self.collection.delete_many({})
+        await self.collection.insert_one({'_id': 0})
 
         for gle_options in [
             {},
@@ -63,17 +61,16 @@ class MotorTestBasic(MotorTest):
 
             if wc.acknowledged:
                 with self.assertRaises(pymongo.errors.DuplicateKeyError):
-                    yield collection.insert_one({'_id': 0})
+                    await collection.insert_one({'_id': 0})
             else:
-                yield collection.insert_one({'_id': 0})  # No error
+                await collection.insert_one({'_id': 0})  # No error
 
             # No error
             c = collection.with_options(write_concern=WriteConcern(w=0))
-            yield c.insert_one({'_id': 0})
+            await c.insert_one({'_id': 0})
             cx.close()
 
     @ignore_deprecations
-    @gen_test
     def test_read_preference(self):
         # Check the default
         cx = motor.MotorClient(test.env.uri, io_loop=self.io_loop)
@@ -132,3 +129,26 @@ class MotorTestBasic(MotorTest):
         # MOTOR-104, TypeError: Can't instantiate abstract class C with abstract
         # methods collection, db, subcollection.
         C()
+
+    @gen_test
+    async def test_inheritance(self):
+        class CollectionSubclass(motor.MotorCollection):
+            pass
+
+        class DatabaseSubclass(motor.MotorDatabase):
+            def __getitem__(self, name):
+                return CollectionSubclass(self, name)
+
+        class ClientSubclass(motor.MotorClient):
+            def __getitem__(self, name):
+                return DatabaseSubclass(self, name)
+
+        cx = ClientSubclass(test.env.uri, **self.get_client_kwargs())
+        self.assertIsInstance(cx, ClientSubclass)
+
+        db = cx['testdb']
+        self.assertIsInstance(db, DatabaseSubclass)
+
+        coll = db['testcoll']
+        self.assertIsInstance(coll, CollectionSubclass)
+        self.assertIsNotNone(await coll.insert_one({}))
