@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals
-
 """Test replica set MotorClient."""
 
 import unittest
@@ -33,8 +31,6 @@ from test.test_environment import db_user, db_password, env
 from test.tornado_tests import MotorReplicaSetTestBase, MotorTest
 from test.utils import one, get_primary_pool
 
-from motor.motor_py2_compat import text_type
-
 
 class MotorReplicaSetTest(MotorReplicaSetTestBase):
     def test_io_loop(self):
@@ -42,7 +38,7 @@ class MotorReplicaSetTest(MotorReplicaSetTestBase):
             motor.MotorClient(test.env.rs_uri, io_loop='foo')
 
     @gen_test
-    def test_connection_failure(self):
+    async def test_connection_failure(self):
         # Assuming there isn't anything actually running on this port
         client = motor.MotorClient(
             'localhost:8765', replicaSet='rs', io_loop=self.io_loop,
@@ -50,51 +46,15 @@ class MotorReplicaSetTest(MotorReplicaSetTestBase):
 
         # Test the Future interface.
         with self.assertRaises(pymongo.errors.ConnectionFailure):
-            yield client.admin.command('ismaster')
+            await client.admin.command('ismaster')
 
     @gen_test
-    def test_auth_network_error(self):
-        if not test.env.auth:
-            raise SkipTest('Authentication is not enabled on server')
-
-        # Make sure there's no semaphore leak if we get a network error
-        # when authenticating a new socket with cached credentials.
-        # Get a client with one socket so we detect if it's leaked.
-        c = self.motor_rsc(maxPoolSize=1, waitQueueTimeoutMS=1,
-                           retryReads=False)
-        yield c.admin.command('ismaster')
-
-        # Simulate an authenticate() call on a different socket.
-        credentials = pymongo.auth._build_credentials_tuple(
-            'DEFAULT',
-            'admin',
-            text_type(db_user),
-            text_type(db_password),
-            {},
-            'admin')
-
-        c.delegate._cache_credentials('test', credentials, connect=False)
-
-        # Cause a network error on the actual socket.
-        pool = get_primary_pool(c)
-        socket_info = one(pool.sockets)
-        socket_info.sock.close()
-
-        # In __check_auth, the client authenticates its socket with the
-        # new credential, but gets a socket.error. Should be reraised as
-        # AutoReconnect.
-        with self.assertRaises(pymongo.errors.AutoReconnect):
-            yield c.test.collection.find_one()
-
-        # No semaphore leak, the pool is allowed to make a new socket.
-        yield c.test.collection.find_one()
-
-    @gen_test
-    def test_open_concurrent(self):
+    async def test_open_concurrent(self):
         # MOTOR-66: don't block on PyMongo's __monitor_lock, but also don't
         # spawn multiple monitors.
         c = self.motor_rsc()
-        yield [c.db.collection.find_one(), c.db.collection.find_one()]
+        await gen.multi(
+            [c.db.collection.find_one(), c.db.collection.find_one()])
 
 
 class TestReplicaSetClientAgainstStandalone(MotorTest):
@@ -102,15 +62,15 @@ class TestReplicaSetClientAgainstStandalone(MotorTest):
     MotorClient but only if the database at DB_IP and DB_PORT is a standalone.
     """
     def setUp(self):
-        super(TestReplicaSetClientAgainstStandalone, self).setUp()
+        super().setUp()
         if test.env.is_replica_set:
             raise SkipTest(
                 "Connected to a replica set, not a standalone mongod")
 
     @gen_test
-    def test_connect(self):
+    async def test_connect(self):
         with self.assertRaises(pymongo.errors.ServerSelectionTimeoutError):
-            yield motor.MotorClient(
+            await motor.MotorClient(
                 '%s:%s' % (env.host, env.port), replicaSet='anything',
                 io_loop=self.io_loop,
                 serverSelectionTimeoutMS=10).test.test.find_one()
