@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals
-
 """Test utilities for using Motor with Tornado web applications."""
 
 import datetime
@@ -37,7 +35,7 @@ from test.test_environment import env, CA_PEM, CLIENT_PEM
 # the convenience of self.fetch().
 class GridFSHandlerTestBase(AsyncHTTPTestCase):
     def setUp(self):
-        super(GridFSHandlerTestBase, self).setUp()
+        super().setUp()
 
         self.fs = gridfs.GridFS(test.env.sync_cx.motor_test)
 
@@ -57,10 +55,10 @@ class GridFSHandlerTestBase(AsyncHTTPTestCase):
 
     def motor_db(self, **kwargs):
         if env.mongod_started_with_ssl:
-            kwargs.setdefault('ssl_certfile', CLIENT_PEM)
-            kwargs.setdefault('ssl_ca_certs', CA_PEM)
+            kwargs.setdefault('tlsCAFile', CA_PEM)
+            kwargs.setdefault('tlsCertificateKeyFile', CLIENT_PEM)
 
-        kwargs.setdefault('ssl', env.mongod_started_with_ssl)
+        kwargs.setdefault('tls', env.mongod_started_with_ssl)
 
         client = motor.MotorClient(
             test.env.uri,
@@ -71,7 +69,7 @@ class GridFSHandlerTestBase(AsyncHTTPTestCase):
 
     def tearDown(self):
         self.fs.delete(self.file_id)
-        super(GridFSHandlerTestBase, self).tearDown()
+        super().tearDown()
         
     def get_app(self):
         return Application([
@@ -186,7 +184,7 @@ class GridFSHandlerTest(GridFSHandlerTestBase):
 
 class TZAwareGridFSHandlerTest(GridFSHandlerTestBase):
     def motor_db(self):
-        return super(TZAwareGridFSHandlerTest, self).motor_db(tz_aware=True)
+        return super().motor_db(tz_aware=True)
 
     def test_tz_aware(self):
         now = datetime.datetime.utcnow()
